@@ -1,4 +1,8 @@
 from .dict import ObjDict
-from .util import sizeof_fmt, image_layout
+from .util import (
+    sizeof_fmt,
+    image_layout,
+    s_hwc_to_chw
+)
 from .resources import ResourceCounter
 from .conf import BaseConfig
\ No newline at end of file
